@@ -4,7 +4,6 @@ import websocket
 import json
 import time
 import logging
-import wsaccel
 import sys
 import json
 import ScratchEncoder
@@ -60,20 +59,6 @@ class s2py():
                 "referer": "",
             }
 
-    def postProfileComment(self, user, content,parentid="",cid=""):
-        data = {
-            "commentee_id": cid,
-            "content": content,
-            "parent_id": parentid,
-        }
-        data = json.dumps(data)
-        self.headers['referer'] = "https://scratch.mit.edu/users/"+user
-        return requests.post(
-            "https://scratch.mit.edu/site-api/comments/user/" + user + "/add/",
-            headers=self.headers,
-            data=data,
-        )
-    
     def decode(self, text):
         return encoder.decode(text)
     
@@ -329,6 +314,15 @@ class s2py():
             })
             time.sleep(0.1)
             logging.info('Re-connected to wss://clouddata.scratch.mit.edu')
+            logging.info('Re-sending the data')
+            sendPacket({
+                'method': 'set',
+                'name': '☁ ' + variable,
+                'value': str(value),
+                'user': self.username,
+                'project_id': str(PROJECT_ID)
+            })
+            time.sleep(0.1)
 
     def readCloudVar(self, name, limit="1000"):
         try:
@@ -354,6 +348,30 @@ class s2py():
         })
         time.sleep(1.5)
 
+    
+    def turbowarpConnect(self, pid):
+        global ws
+        global PROJECT_ID
+        PROJECT_ID = pid
+        ws.connect('wss://clouddata.turbowarp.org',
+               origin='https://turbowarp.org', enable_multithread=True)
+        sendPacket({
+            'method': 'handshake',
+            'user': self.username,
+            'project_id': str(pid)
+        })
+        time.sleep(1.5)
+
+
+    def setTurbowarpVar(self, variable, value):
+        sendPacket({
+            'method': 'set',
+            'name': '☁ ' + variable,
+            'value': str(value),
+            'user': self.username,
+            'project_id': str(PROJECT_ID)
+        })
+        time.sleep(0.1)
 
 def sendPacket(packet):
     ws.send(json.dumps(packet) + '\n')
